<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdFemCreateFromShape</name>
    <message>
      <location filename="../../Command.cpp" line="+50"/>
      <source>Fem</source>
      <translation>Metoda konačnih elemenata</translation>
    </message>
    <message>
      <source>Create FEM mesh</source>
      <translation>Napravi MKE mrežu</translation>
    </message>
    <message>
      <source>Create FEM mesh from shape</source>
      <translation>Napravite MKE mrežu od oblika</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+38"/>
      <source>FEM</source>
      <translation>MKE</translation>
    </message>
    <message>
      <source>&amp;FEM</source>
      <translation>&amp;MKE</translation>
    </message>
  </context>
</TS>
